TReadTransportFactory

Trait TReadTransportFactory 

pub trait TReadTransportFactory {
    // Required method
    fn create(
        &self,
        channel: Box<dyn Read + Send>,
    ) -> Box<dyn TReadTransport + Send>;
}
Helper type used by a server to create TReadTransport instances for accepted client connections.

Required Methods

fn create( &self, channel: Box<dyn Read + Send>, ) -> Box<dyn TReadTransport + Send>

Create a TTransport that wraps a channel over which bytes are to be read.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> TReadTransportFactory for Box<T>

Source

fn create( &self, channel: Box<dyn Read + Send>, ) -> Box<dyn TReadTransport + Send>

Implementors