TWriteTransportFactory

Trait TWriteTransportFactory 

pub trait TWriteTransportFactory {
    // Required method
    fn create(
        &self,
        channel: Box<dyn Write + Send>,
    ) -> Box<dyn TWriteTransport + Send>;
}
Helper type used by a server to create TWriteTransport instances for accepted client connections.

Required Methods

fn create( &self, channel: Box<dyn Write + Send>, ) -> Box<dyn TWriteTransport + Send>

Create a TTransport that wraps a channel over which bytes are to be sent.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> TWriteTransportFactory for Box<T>

Source

fn create( &self, channel: Box<dyn Write + Send>, ) -> Box<dyn TWriteTransport + Send>

Implementors